@@ -13,7 +13,7 @@
 #define PAGE_READONLY		__pgprot(0) /* these mean nothing to NO_MM */
 #define PAGE_KERNEL		__pgprot(0) /* these mean nothing to NO_MM */
 
-extern void paging_init(void);
+extern void paging_init(struct meminfo *);
 
 #define pgtable_cache_init()   ((void)0)
 
